Installation
=============================================================
To install Episuite, just use ``pip`` like below:

.. code-block:: bash

    pip install episuite

And that is it, ``pip`` will install all required dependencies.